@@ -9,7 +9,7 @@ use constant DEFAULT_MAXPROCS      => 1;
 use constant DEFAULT_REAP_TIMEOUT  => .1;
 use constant DEFAULT_TOTALPROCS    => 1;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 =head1 NAME
 
@@ -115,7 +115,7 @@ sub run {
         # parent work
         my $pid = fork();
         if ($pid) {
-            $self->{_totalprocs}-- if $self->{_totalprocs} > 0;
+            $self->{_totalprocs}-- if defined $self->{_totalprocs} and $self->{_totalprocs} > 0;
             $self->{_jobs}{$pid} = 1;
             next;
         }
